@@ -4,6 +4,7 @@ import (
 	"errors"
 	"os"
 	"path/filepath"
+	"strings"
 
 	"github.com/gsamokovarov/jump/cli"
 	"github.com/gsamokovarov/jump/config"
@@ -33,31 +34,39 @@ const noEntriesMessage = `Jump's database is empty. This could mean:
 `
 
 func cdCmd(args cli.Args, conf config.Config) error {
-	term := termFromArgs(args, conf)
+	var term, baseDir string
+	if filepath.IsAbs(args.First()) && dirIsAccessible(args.First()) && len(args) > 1 {
+		baseDir = args.First()
+		term = termFromArgs(args.Rest(), conf)
+	} else {
+		term = termFromArgs(args, conf)
+	}
 
-	entry, err := cdEntry(term, conf)
+	path, err := cdEntry(term, baseDir, conf)
 	if errors.Is(err, errNoEntries) {
 		cli.Errf(noEntriesMessage)
 		return nil
-	}
-	if err != nil {
+	} else if err != nil {
 		return err
 	}
 
-	cli.Outf("%s\n", entry.Path)
+	cli.Outf("%s\n", path)
 
 	return nil
 }
 
-func cdEntry(term string, conf config.Config) (*scoring.Entry, error) {
+func cdEntry(term, baseDir string, conf config.Config) (string, error) {
 	entries, err := conf.ReadEntries()
 	if err != nil {
-		return nil, err
+		return "", err
+	}
+	if baseDir != "" {
+		entries = entries.Under(baseDir)
 	}
 
 	// If an auto-completion triggered a full path, just go there.
 	if filepath.IsAbs(term) {
-		return scoring.NewEntry(term), nil
+		return term, nil
 	}
 
 	index, search := 0, conf.ReadSearch()
@@ -73,13 +82,21 @@ func cdEntry(term string, conf config.Config) (*scoring.Entry, error) {
 			// Except if we land on the current directory again. Then
 			// ignore the term.
 			if !fwdPathIsCwd(dir) {
-				return scoring.NewEntry(dir), nil
+				return dir, nil
 			}
 		}
 	}
 
-	settings := conf.ReadSettings()
+	// If the directory exists under the cwd, go there.
+	cwd, err := os.Getwd()
+	if termIsRelative(term) && err == nil {
+		relativeDir := filepath.Join(cwd, term)
+		if dirIsAccessible(relativeDir) {
+			return relativeDir, nil
+		}
+	}
 
+	settings := conf.ReadSettings()
 	fuzzyEntries := scoring.NewFuzzyEntries(entries, term)
 
 	// Prefer an exact match if it's in a reasonable proximity of the best
@@ -105,17 +122,18 @@ func cdEntry(term string, conf config.Config) (*scoring.Entry, error) {
 				continue
 			}
 
-			if err := conf.WriteSearch(term, index); err != nil {
-				return nil, err
-			}
+			return entry.Path, conf.WriteSearch(term, index)
+		}
 
-			return entry, nil
+		// If we're given a base directory, and there is no match, go to the base.
+		if baseDir != "" {
+			return baseDir, nil
 		}
 
 		break
 	}
 
-	return nil, errNoEntries
+	return "", errNoEntries
 }
 
 const exactMatchProximity = 5
@@ -159,6 +177,19 @@ func fwdPathIsCwd(path string) bool {
 	return fwdPath == cwd
 }
 
+func dirIsAccessible(path string) bool {
+	fi, err := os.Stat(path)
+	if err != nil {
+		return false
+	}
+
+	return fi.IsDir()
+}
+
+func termIsRelative(term string) bool {
+	return strings.Contains(term, "/")
+}
+
 func init() {
 	cli.RegisterCommand("cd", "Fuzzy match a directory to jump to.", cdCmd)
 }
